==> qtjambi-datavisualization-6.5.7-sources.jar: io/qt/datavis/QtJambi_LibraryUtilities.java <==
package io.qt.datavis;

import io.qt.*;
import static io.qt.QtUtilities.*;

/**
 * @hidden
 */
final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 5;

    final static int qtJambiPatch = 7;

    final static InternalAccess internal;

    static{
        try {
            initializePackage("io.qt.core");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly, "macos", "linux");
            loadQtLibrary("EglFSDeviceIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Pdf", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WaylandEglClientHwIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("XcbQpa", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.ProvideOnly, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("OpenGL", LibraryRequirementMode.Mandatory);
            loadQtLibrary("DataVisualization", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("DataVisualization");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-datavisualization-6.6.0-sources.jar: io/qt/datavis/QtJambi_LibraryUtilities.java <==
package io.qt.datavis;

import io.qt.*;
import static io.qt.QtUtilities.*;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 6;

    final static int qtJambiPatch = 0;

    final static InternalAccess internal;

    static{
        try {
            initializePackage("io.qt.core");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly, "macos", "linux");
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Qml", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QmlModels", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Quick", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("VirtualKeyboard", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WaylandEglClientHwIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.ProvideOnly, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("OpenGL", LibraryRequirementMode.Mandatory);
            loadQtLibrary("DataVisualization", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("DataVisualization");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
